==> sugarcrm-6.2.1.tbz: www/sugarcrm/modules/Prospects/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_MODULE_NAME' => 'Targets',
  'LBL_MODULE_ID'   => 'Targets',
  'LBL_INVITEE' => 'Direct Reports',
  'LBL_MODULE_TITLE' => 'Targets: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Target Search',
  'LBL_LIST_FORM_TITLE' => 'Target List',
  'LBL_NEW_FORM_TITLE' => 'New Target',
  'LBL_PROSPECT' => 'Target:',
  'LBL_BUSINESSCARD' => 'Business Card',
  'LBL_LIST_NAME' => 'Name',
  'LBL_LIST_LAST_NAME' => 'Last Name',
  'LBL_LIST_PROSPECT_NAME' => 'Target Name',
  'LBL_LIST_TITLE' => 'Title',
  'LBL_LIST_EMAIL_ADDRESS' => 'Email',
  'LBL_LIST_OTHER_EMAIL_ADDRESS' => 'Other Email',
  'LBL_LIST_PHONE' => 'Phone',
  'LBL_LIST_PROSPECT_ROLE' => 'Role',
  'LBL_LIST_FIRST_NAME' => 'First Name',
  'LBL_ASSIGNED_TO_NAME' => 'Assigned to',
  'LBL_ASSIGNED_TO_ID'=>'Assigned To:',
//DON'T CONVERT THESE THEY ARE MAPPINGS
  'db_last_name' => 'LBL_LIST_LAST_NAME',
  'db_first_name' => 'LBL_LIST_FIRST_NAME',
  'db_title' => 'LBL_LIST_TITLE',
  'db_email1' => 'LBL_LIST_EMAIL_ADDRESS',
  'db_email2' => 'LBL_LIST_OTHER_EMAIL_ADDRESS',
//END DON'T CONVERT
  'LBL_CAMPAIGN_ID' => 'Campaign ID',
  'LBL_EXISTING_PROSPECT' => 'Used an existing contact',
  'LBL_CREATED_PROSPECT' => 'Created a new contact',
  'LBL_EXISTING_ACCOUNT' => 'Used an existing account',
  'LBL_CREATED_ACCOUNT' => 'Created a new account',
  'LBL_CREATED_CALL' => 'Created a new call',
  'LBL_CREATED_MEETING' => 'Created a new meeting',
  'LBL_ADDMORE_BUSINESSCARD' => 'Add another business card',
  'LBL_ADD_BUSINESSCARD' => 'Enter Business Card',
  'LBL_NAME' => 'Name:',
  'LBL_FULL_NAME' => 'Name',
  'LBL_PROSPECT_NAME' => 'Target Name:',
  'LBL_PROSPECT_INFORMATION' => 'Target Overview',
  'LBL_MORE_INFORMATION' => 'More Information',
  'LBL_FIRST_NAME' => 'First Name:',
  'LBL_OFFICE_PHONE' => 'Office Phone:',
  'LBL_ANY_PHONE' => 'Any Phone:',
  'LBL_PHONE' => 'Phone:',
  'LBL_LAST_NAME' => 'Last Name:',
  'LBL_MOBILE_PHONE' => 'Mobile:',
  'LBL_HOME_PHONE' => 'Home:',
  'LBL_OTHER_PHONE' => 'Other Phone:',
  'LBL_FAX_PHONE' => 'Fax:',
  'LBL_PRIMARY_ADDRESS_STREET' => 'Primary Address Street:',
  'LBL_PRIMARY_ADDRESS_CITY' => 'Primary Address City:',
  'LBL_PRIMARY_ADDRESS_COUNTRY' => 'Primary Address Country:',
  'LBL_PRIMARY_ADDRESS_STATE' => 'Primary Address State:',
  'LBL_PRIMARY_ADDRESS_POSTALCODE' => 'Primary Address Postal Code:',
  'LBL_ALT_ADDRESS_STREET' => 'Alternate Address Street:',
  'LBL_ALT_ADDRESS_CITY' => 'Alternate Address City:',
  'LBL_ALT_ADDRESS_COUNTRY' => 'Alternate Address Country:',
  'LBL_ALT_ADDRESS_STATE' => 'Alternate Address State:',
  'LBL_ALT_ADDRESS_POSTALCODE' => 'Alternate Address Postal Code:',
  'LBL_TITLE' => 'Title:',
  'LBL_DEPARTMENT' => 'Department:',
  'LBL_BIRTHDATE' => 'Birthdate:',
  'LBL_EMAIL_ADDRESS' => 'Email Address:',
  'LBL_OTHER_EMAIL_ADDRESS' => 'Other Email:',
  'LBL_ANY_EMAIL' => 'Any Email:',
  'LBL_ASSISTANT' => 'Assistant:',
  'LBL_ASSISTANT_PHONE' => 'Assistant Phone:',
  'LBL_DO_NOT_CALL' => 'Do Not Call:',
  'LBL_EMAIL_OPT_OUT' => 'Email Opt Out:',
  'LBL_PRIMARY_ADDRESS' => 'Primary Address:',
  'LBL_ALTERNATE_ADDRESS' => 'Other Address:',
  'LBL_ANY_ADDRESS' => 'Any Address:',
  'LBL_CITY' => 'City:',
  'LBL_STATE' => 'State:',
  'LBL_POSTAL_CODE' => 'Postal Code:',
  'LBL_COUNTRY' => 'Country:',
  'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
  'LBL_ADDRESS_INFORMATION' => 'Address Information',
  'LBL_DESCRIPTION' => 'Description:',
  'LBL_PROSPECT_ROLE' => 'Role:',
  'LBL_OPP_NAME' => 'Opportunity Name:',
  'LBL_IMPORT_VCARD' => 'Import vCard',
  'LBL_IMPORT_VCARDTEXT' => 'Automatically create a new contact by importing a vCard from your file system.',
  'LBL_DUPLICATE' => 'Possible Duplicate Targets',
  'MSG_SHOW_DUPLICATES' => 'The target record you are about to create might be a duplicate of a target record that already exists. Target records containing similar names and/or email addresses are listed below.<br>Click Create Target to continue creating this new target, or select an existing target listed below.',
  'MSG_DUPLICATE' => 'The target record you are about to create might be a duplicate of a target record that already exists. Target records containing similar names and/or email addresses are listed below.<br>Click Save to continue creating this new target, or click Cancel to return to the module without creating the target.',
  'LNK_IMPORT_VCARD' => 'Create From vCard',
  'LNK_NEW_ACCOUNT' => 'Create Account',
  'LNK_NEW_OPPORTUNITY' => 'Create Opportunity',
  'LNK_NEW_CASE' => 'Create Case',
  'LNK_NEW_NOTE' => 'Create Note or Attachment',
  'LNK_NEW_CALL' => 'Log Call',
  'LNK_NEW_EMAIL' => 'Archive Email',
  'LNK_NEW_MEETING' => 'Schedule Meeting',
  'LNK_NEW_TASK' => 'Create Task',
  'LNK_NEW_APPOINTMENT' => 'Create Appointment',
  'LNK_IMPORT_PROSPECTS' => 'Import Prospects',
  'NTC_DELETE_CONFIRMATION' => 'Are you sure you want to delete this record?',
  'NTC_REMOVE_CONFIRMATION' => 'Are you sure you want to remove this contact from the case?',
  'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION' => 'Are you sure you want to remove this record as a direct report?',
  'ERR_DELETE_RECORD' => 'A record number must be specified to delete the contact.',
  'NTC_COPY_PRIMARY_ADDRESS' => 'Copy primary address to alternate address',
  'NTC_COPY_ALTERNATE_ADDRESS' => 'Copy alternate address to primary address',
  'LBL_SALUTATION' => 'Salutation',
  'LBL_SAVE_PROSPECT' => 'Save Target',
  'LBL_CREATED_OPPORTUNITY' =>'Created a new opportunity',
  'NTC_OPPORTUNITY_REQUIRES_ACCOUNT' => 'Creating an opportunity requires an account.\n Please either create a new account or select an existing one.',
  'LNK_SELECT_ACCOUNT' => "Select Account",
  'LNK_NEW_PROSPECT' => 'Create Target',
  'LNK_PROSPECT_LIST' => 'View Targets',
  'LNK_NEW_CAMPAIGN' => 'Create Campaign',
  'LNK_CAMPAIGN_LIST' => 'Campaigns',
  'LNK_NEW_PROSPECT_LIST' => 'Create Target List',
  'LNK_PROSPECT_LIST_LIST' => 'Target Lists',
  'LNK_IMPORT_PROSPECT' => 'Import Targets',
  'LBL_SELECT_CHECKED_BUTTON_LABEL' => 'Select Checked Targets',
  'LBL_SELECT_CHECKED_BUTTON_TITLE' => 'Select Checked Targets',
  'LBL_INVALID_EMAIL'=>'Invalid Email:',
  'LBL_DEFAULT_SUBPANEL_TITLE'=>'Targets',
  'LBL_PROSPECT_LIST' => 'Prospect List',
  'LBL_CONVERT_BUTTON_KEY' => 'V',
  'LBL_CONVERT_BUTTON_TITLE' => 'Convert Target',
  'LBL_CONVERT_BUTTON_LABEL' => 'Convert Target',
  'LBL_CONVERTPROSPECT'=>'Convert Target',
  'LNK_NEW_CONTACT'=>'New Contact',
  'LBL_CREATED_CONTACT'=>"Created a new contact",
  'LBL_BACKTO_PROSPECTS'=>'Back to Targets',
  'LBL_CAMPAIGNS'=>'Campaigns',
  'LBL_CAMPAIGN_LIST_SUBPANEL_TITLE'=>'Campaign Log',
  'LBL_TRACKER_KEY'=>'Tracker Key',
  'LBL_LEAD_ID'=>'Lead Id',
  'LBL_CONVERTED_LEAD'=>'Converted Lead',
  'LBL_ACCOUNT_NAME'=>'Account Name',
  'LBL_EDIT_ACCOUNT_NAME'=>'Account Name:',
  'LBL_CREATED_USER' => 'Created User',
  'LBL_MODIFIED_USER' => 'Modified User',
  'LBL_CAMPAIGNS_SUBPANEL_TITLE' => 'Campaigns',
  'LBL_HISTORY_SUBPANEL_TITLE'=>'History',
);
?>

==> sugarcrm-6.4.4.tbz: www/sugarcrm/modules/Prospects/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2012 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_MODULE_NAME' => 'Targets',
  'LBL_MODULE_ID'   => 'Targets',
  'LBL_INVITEE' => 'Direct Reports',
  'LBL_MODULE_TITLE' => 'Targets: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Target Search',
  'LBL_LIST_FORM_TITLE' => 'Target List',
  'LBL_NEW_FORM_TITLE' => 'New Target',
  'LBL_PROSPECT' => 'Target:',
  'LBL_BUSINESSCARD' => 'Business Card',
  'LBL_LIST_NAME' => 'Name',
  'LBL_LIST_LAST_NAME' => 'Last Name',
  'LBL_LIST_PROSPECT_NAME' => 'Target Name',
  'LBL_LIST_TITLE' => 'Title',
  'LBL_LIST_EMAIL_ADDRESS' => 'Email',
  'LBL_LIST_OTHER_EMAIL_ADDRESS' => 'Other Email',
  'LBL_LIST_PHONE' => 'Phone',
  'LBL_LIST_PROSPECT_ROLE' => 'Role',
  'LBL_LIST_FIRST_NAME' => 'First Name',
  'LBL_ASSIGNED_TO_NAME' => 'Assigned to',
  'LBL_ASSIGNED_TO_ID'=>'Assigned To:',
//DON'T CONVERT THESE THEY ARE MAPPINGS
  'db_last_name' => 'LBL_LIST_LAST_NAME',
  'db_first_name' => 'LBL_LIST_FIRST_NAME',
  'db_title' => 'LBL_LIST_TITLE',
  'db_email1' => 'LBL_LIST_EMAIL_ADDRESS',
  'db_email2' => 'LBL_LIST_OTHER_EMAIL_ADDRESS',
//END DON'T CONVERT
  'LBL_CAMPAIGN_ID' => 'Campaign ID',
  'LBL_EXISTING_PROSPECT' => 'Used an existing contact',
  'LBL_CREATED_PROSPECT' => 'Created a new contact',
  'LBL_EXISTING_ACCOUNT' => 'Used an existing account',
  'LBL_CREATED_ACCOUNT' => 'Created a new account',
  'LBL_CREATED_CALL' => 'Created a new call',
  'LBL_CREATED_MEETING' => 'Created a new meeting',
  'LBL_ADDMORE_BUSINESSCARD' => 'Add another business card',
  'LBL_ADD_BUSINESSCARD' => 'Enter Business Card',
  'LBL_NAME' => 'Name:',
  'LBL_FULL_NAME' => 'Name',
  'LBL_PROSPECT_NAME' => 'Target Name:',
  'LBL_PROSPECT_INFORMATION' => 'Overview',
  'LBL_MORE_INFORMATION' => 'More Information',
  'LBL_FIRST_NAME' => 'First Name:',
  'LBL_OFFICE_PHONE' => 'Office Phone:',
  'LBL_ANY_PHONE' => 'Any Phone:',
  'LBL_PHONE' => 'Phone:',
  'LBL_LAST_NAME' => 'Last Name:',
  'LBL_MOBILE_PHONE' => 'Mobile:',
  'LBL_HOME_PHONE' => 'Home:',
  'LBL_OTHER_PHONE' => 'Other Phone:',
  'LBL_FAX_PHONE' => 'Fax:',
  'LBL_PRIMARY_ADDRESS_STREET' => 'Primary Address Street:',
  'LBL_PRIMARY_ADDRESS_CITY' => 'Primary Address City:',
  'LBL_PRIMARY_ADDRESS_COUNTRY' => 'Primary Address Country:',
  'LBL_PRIMARY_ADDRESS_STATE' => 'Primary Address State:',
  'LBL_PRIMARY_ADDRESS_POSTALCODE' => 'Primary Address Postal Code:',
  'LBL_ALT_ADDRESS_STREET' => 'Alternate Address Street:',
  'LBL_ALT_ADDRESS_CITY' => 'Alternate Address City:',
  'LBL_ALT_ADDRESS_COUNTRY' => 'Alternate Address Country:',
  'LBL_ALT_ADDRESS_STATE' => 'Alternate Address State:',
  'LBL_ALT_ADDRESS_POSTALCODE' => 'Alternate Address Postal Code:',
  'LBL_TITLE' => 'Title:',
  'LBL_DEPARTMENT' => 'Department:',
  'LBL_BIRTHDATE' => 'Birthdate:',
  'LBL_EMAIL_ADDRESS' => 'Email Address:',
  'LBL_OTHER_EMAIL_ADDRESS' => 'Other Email:',
  'LBL_ANY_EMAIL' => 'Any Email:',
  'LBL_ASSISTANT' => 'Assistant:',
  'LBL_ASSISTANT_PHONE' => 'Assistant Phone:',
  'LBL_DO_NOT_CALL' => 'Do Not Call:',
  'LBL_EMAIL_OPT_OUT' => 'Email Opt Out:',
  'LBL_PRIMARY_ADDRESS' => 'Primary Address:',
  'LBL_ALTERNATE_ADDRESS' => 'Other Address:',
  'LBL_ANY_ADDRESS' => 'Any Address:',
  'LBL_CITY' => 'City:',
  'LBL_STATE' => 'State:',
  'LBL_POSTAL_CODE' => 'Postal Code:',
  'LBL_COUNTRY' => 'Country:',
  'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
  'LBL_ADDRESS_INFORMATION' => 'Address Information',
  'LBL_DESCRIPTION' => 'Description:',
  'LBL_PROSPECT_ROLE' => 'Role:',
  'LBL_OPP_NAME' => 'Opportunity Name:',
  'LBL_IMPORT_VCARD' => 'Import vCard',
  'LBL_IMPORT_VCARDTEXT' => 'Automatically create a new contact by importing a vCard from your file system.',
  'LBL_DUPLICATE' => 'Possible Duplicate Targets',
  'MSG_SHOW_DUPLICATES' => 'The target record you are about to create might be a duplicate of a target record that already exists. Target records containing similar names and/or email addresses are listed below.<br>Click Create Target to continue creating this new target, or select an existing target listed below.',
  'MSG_DUPLICATE' => 'The target record you are about to create might be a duplicate of a target record that already exists. Target records containing similar names and/or email addresses are listed below.<br>Click Save to continue creating this new target, or click Cancel to return to the module without creating the target.',
  'LNK_IMPORT_VCARD' => 'Create From vCard',
  'LNK_NEW_ACCOUNT' => 'Create Account',
  'LNK_NEW_OPPORTUNITY' => 'Create Opportunity',
  'LNK_NEW_CASE' => 'Create Case',
  'LNK_NEW_NOTE' => 'Create Note or Attachment',
  'LNK_NEW_CALL' => 'Log Call',
  'LNK_NEW_EMAIL' => 'Archive Email',
  'LNK_NEW_MEETING' => 'Schedule Meeting',
  'LNK_NEW_TASK' => 'Create Task',
  'LNK_NEW_APPOINTMENT' => 'Create Appointment',
  'LNK_IMPORT_PROSPECTS' => 'Import Prospects',
  'NTC_DELETE_CONFIRMATION' => 'Are you sure you want to delete this record?',
  'NTC_REMOVE_CONFIRMATION' => 'Are you sure you want to remove this contact from the case?',
  'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION' => 'Are you sure you want to remove this record as a direct report?',
  'ERR_DELETE_RECORD' => 'A record number must be specified to delete the contact.',
  'NTC_COPY_PRIMARY_ADDRESS' => 'Copy primary address to alternate address',
  'NTC_COPY_ALTERNATE_ADDRESS' => 'Copy alternate address to primary address',
  'LBL_SALUTATION' => 'Salutation',
  'LBL_SAVE_PROSPECT' => 'Save Target',
  'LBL_CREATED_OPPORTUNITY' =>'Created a new opportunity',
  'NTC_OPPORTUNITY_REQUIRES_ACCOUNT' => 'Creating an opportunity requires an account.\n Please either create a new account or select an existing one.',
  'LNK_SELECT_ACCOUNT' => "Select Account",
  'LNK_NEW_PROSPECT' => 'Create Target',
  'LNK_PROSPECT_LIST' => 'View Targets',
  'LNK_NEW_CAMPAIGN' => 'Create Campaign',
  'LNK_CAMPAIGN_LIST' => 'Campaigns',
  'LNK_NEW_PROSPECT_LIST' => 'Create Target List',
  'LNK_PROSPECT_LIST_LIST' => 'Target Lists',
  'LNK_IMPORT_PROSPECT' => 'Import Targets',
  'LBL_SELECT_CHECKED_BUTTON_LABEL' => 'Select Checked Targets',
  'LBL_SELECT_CHECKED_BUTTON_TITLE' => 'Select Checked Targets',
  'LBL_INVALID_EMAIL'=>'Invalid Email:',
  'LBL_DEFAULT_SUBPANEL_TITLE'=>'Targets',
  'LBL_PROSPECT_LIST' => 'Prospect List',
  'LBL_CONVERT_BUTTON_KEY' => 'V',
  'LBL_CONVERT_BUTTON_TITLE' => 'Convert Target',
  'LBL_CONVERT_BUTTON_LABEL' => 'Convert Target',
  'LBL_CONVERTPROSPECT'=>'Convert Target',
  'LNK_NEW_CONTACT'=>'New Contact',
  'LBL_CREATED_CONTACT'=>"Created a new contact",
  'LBL_BACKTO_PROSPECTS'=>'Back to Targets',
  'LBL_CAMPAIGNS'=>'Campaigns',
  'LBL_CAMPAIGN_LIST_SUBPANEL_TITLE'=>'Campaign Log',
  'LBL_TRACKER_KEY'=>'Tracker Key',
  'LBL_LEAD_ID'=>'Lead Id',
  'LBL_CONVERTED_LEAD'=>'Converted Lead',
  'LBL_ACCOUNT_NAME'=>'Account Name',
  'LBL_EDIT_ACCOUNT_NAME'=>'Account Name:',
  'LBL_CREATED_USER' => 'Created User',
  'LBL_MODIFIED_USER' => 'Modified User',
  'LBL_CAMPAIGNS_SUBPANEL_TITLE' => 'Campaigns',
  'LBL_HISTORY_SUBPANEL_TITLE'=>'History',
  //For export labels
  'LBL_PHONE_HOME' => 'Phone Home',
  'LBL_PHONE_MOBILE' => 'Phone Mobile',
  'LBL_PHONE_WORK' => 'Phone Work',
  'LBL_PHONE_OTHER' => 'Phone Other',
  'LBL_PHONE_FAX' => 'Phone Fax',
  'LBL_CAMPAIGN_ID' => 'Campaign ID',
  'LBL_EXPORT_ASSIGNED_USER_NAME' => 'Assigned User Name',
  'LBL_EXPORT_ASSIGNED_USER_ID' => 'Assigned User ID',
  'LBL_EXPORT_MODIFIED_USER_ID' => 'Modified By ID',
  'LBL_EXPORT_CREATED_BY' => 'Created By ID',
  'LBL_EXPORT_EMAIL2'=>'Other Email Address',
);
?>
